@@ -206,6 +206,10 @@ extern "C" {
 #define IPMI_SUPERMICRO_PRODUCT_ID_X9SCM       __IPMI_SUPERMICRO_PRODUCT_ID_X9SC
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTNPLUS_F 1551
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8SIE       1037
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCA_F_O   1585
+
+/* Seen in the wild w/ proper IANA number 10876 */
+/* defined above: IPMI_SUPERMICRO_PRODUCT_ID_X9SCM */
 
 /* Seen in the wild w/ Magnum Technologies IANA number 5593 */
 /* defined above: IPMI_SUPERMICRO_PRODUCT_ID_X8DTL */
