@@ -62,6 +62,7 @@
 #include "ipmi-sel-parse-common.h"
 #include "ipmi-sel-parse-defs.h"
 #include "ipmi-sel-parse-string.h"
+#include "ipmi-sel-parse-string-intel-node-manager.h"
 #include "ipmi-sel-parse-string-quanta.h"
 #include "ipmi-sel-parse-trace.h"
 #include "ipmi-sel-parse-util.h"
@@ -70,6 +71,108 @@
 
 #define QUANTA_EVENT_BUFFER_LENGTH 4096
 
+int
+ipmi_sel_parse_output_quanta_sensor_name (ipmi_sel_parse_ctx_t ctx,
+					  struct ipmi_sel_parse_entry *sel_parse_entry,
+					  uint8_t sel_record_type,
+					  char *buf,
+					  unsigned int buflen,
+					  unsigned int flags,
+					  unsigned int *wlen,
+					  struct ipmi_sel_system_event_record_data *system_event_record_data,
+					  int *oem_rv)
+{
+  assert (ctx);
+  assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
+  assert (sel_parse_entry);
+  assert (buf);
+  assert (buflen);
+  assert (!(flags & ~IPMI_SEL_PARSE_STRING_MASK));
+  assert (flags & IPMI_SEL_PARSE_STRING_FLAGS_INTERPRET_OEM_DATA);
+  assert (wlen);
+  assert (system_event_record_data);
+  assert (oem_rv);
+
+  /* OEM Interpretation
+   *
+   * Quanta S99Q/Dell FS12-TY
+   */
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+    {
+      int nmret;
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_sensor_name (ctx,
+									 sel_parse_entry,
+									 sel_record_type,
+									 buf,
+									 buflen,
+									 flags,
+									 wlen,
+									 system_event_record_data,
+									 oem_rv)) < 0)
+        return (-1);
+      
+      if (nmret)
+        return (1);      
+    }
+  
+  return (0);
+}
+
+/* return (0) - no OEM match
+ * return (1) - OEM match
+ * return (-1) - error, cleanup and return error
+ *
+ * 0 - continue on
+ * 1 - buffer full, return full buffer to user
+ */
+int
+ipmi_sel_parse_output_quanta_event_data1_class_oem (ipmi_sel_parse_ctx_t ctx,
+                                                    struct ipmi_sel_parse_entry *sel_parse_entry,
+                                                    uint8_t sel_record_type,
+                                                    char *tmpbuf,
+                                                    unsigned int tmpbuflen,
+                                                    unsigned int flags,
+                                                    unsigned int *wlen,
+                                                    struct ipmi_sel_system_event_record_data *system_event_record_data)
+{
+  assert (ctx);
+  assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
+  assert (sel_parse_entry);
+  assert (tmpbuf);
+  assert (tmpbuflen);
+  assert (!(flags & ~IPMI_SEL_PARSE_STRING_MASK));
+  assert (flags & IPMI_SEL_PARSE_STRING_FLAGS_INTERPRET_OEM_DATA);
+  assert (wlen);
+  assert (system_event_record_data);
+
+  /* OEM Interpretation
+   *
+   * Quanta S99Q/Dell FS12-TY
+   */
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+    {
+      int nmret;
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data1_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+
+      if (nmret)
+        return (1);
+    }
+
+  return (0);
+}
+
 /* return (0) - no OEM match
  * return (1) - OEM match
  * return (-1) - error, cleanup and return error
@@ -89,6 +192,7 @@ ipmi_sel_parse_output_quanta_event_data2_discrete_oem (ipmi_sel_parse_ctx_t ctx,
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -100,10 +204,9 @@ ipmi_sel_parse_output_quanta_event_data2_discrete_oem (ipmi_sel_parse_ctx_t ctx,
 
   /* OEM Interpretation
    *
-   * Quanta S99Q/Dell TS12-TY
+   * Quanta S99Q/Dell FS12-TY
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA
-      && ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
     {
       if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_QUANTA_ERROR
           && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_CRITICAL_INTERRUPT
@@ -162,17 +265,71 @@ ipmi_sel_parse_output_quanta_event_data2_discrete_oem (ipmi_sel_parse_ctx_t ctx,
  * 1 - buffer full, return full buffer to user
  */
 int
-ipmi_sel_parse_output_quanta_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ctx,
-							 struct ipmi_sel_parse_entry *sel_parse_entry,
-							 uint8_t sel_record_type,
-							 char *tmpbuf,
-							 unsigned int tmpbuflen,
-							 unsigned int flags,
-							 unsigned int *wlen,
-							 struct ipmi_sel_system_event_record_data *system_event_record_data)
+ipmi_sel_parse_output_quanta_event_data2_class_oem (ipmi_sel_parse_ctx_t ctx,
+                                                    struct ipmi_sel_parse_entry *sel_parse_entry,
+                                                    uint8_t sel_record_type,
+                                                    char *tmpbuf,
+                                                    unsigned int tmpbuflen,
+                                                    unsigned int flags,
+                                                    unsigned int *wlen,
+                                                    struct ipmi_sel_system_event_record_data *system_event_record_data)
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
+  assert (sel_parse_entry);
+  assert (tmpbuf);
+  assert (tmpbuflen);
+  assert (!(flags & ~IPMI_SEL_PARSE_STRING_MASK));
+  assert (flags & IPMI_SEL_PARSE_STRING_FLAGS_INTERPRET_OEM_DATA);
+  assert (wlen);
+  assert (system_event_record_data);
+
+  /* OEM Interpretation
+   *
+   * Quanta S99Q/Dell FS12-TY
+   */
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+    {
+      int nmret;
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data2_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+
+      if (nmret)
+        return (1);
+    }
+
+  return (0);
+}
+
+/* return (0) - no OEM match
+ * return (1) - OEM match
+ * return (-1) - error, cleanup and return error
+ *
+ * 0 - continue on
+ * 1 - buffer full, return full buffer to user
+ */
+int
+ipmi_sel_parse_output_quanta_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ctx,
+						       struct ipmi_sel_parse_entry *sel_parse_entry,
+						       uint8_t sel_record_type,
+						       char *tmpbuf,
+						       unsigned int tmpbuflen,
+						       unsigned int flags,
+						       unsigned int *wlen,
+						       struct ipmi_sel_system_event_record_data *system_event_record_data)
+{
+  assert (ctx);
+  assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -184,10 +341,9 @@ ipmi_sel_parse_output_quanta_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ctx,
 
   /* OEM Interpretation
    *
-   * Quanta S99Q/Dell TS12-TY
+   * Quanta S99Q/Dell FS12-TY
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA
-      && ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
     {
       if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_QUANTA_ERROR
           && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_MEMORY
@@ -308,3 +464,56 @@ ipmi_sel_parse_output_quanta_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ctx,
 
   return (0);
 }
+
+/* return (0) - no OEM match
+ * return (1) - OEM match
+ * return (-1) - error, cleanup and return error
+ *
+ * 0 - continue on
+ * 1 - buffer full, return full buffer to user
+ */
+int
+ipmi_sel_parse_output_quanta_event_data3_class_oem (ipmi_sel_parse_ctx_t ctx,
+                                                    struct ipmi_sel_parse_entry *sel_parse_entry,
+                                                    uint8_t sel_record_type,
+                                                    char *tmpbuf,
+                                                    unsigned int tmpbuflen,
+                                                    unsigned int flags,
+                                                    unsigned int *wlen,
+                                                    struct ipmi_sel_system_event_record_data *system_event_record_data)
+{
+  assert (ctx);
+  assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_QUANTA);
+  assert (sel_parse_entry);
+  assert (tmpbuf);
+  assert (tmpbuflen);
+  assert (!(flags & ~IPMI_SEL_PARSE_STRING_MASK));
+  assert (flags & IPMI_SEL_PARSE_STRING_FLAGS_INTERPRET_OEM_DATA);
+  assert (wlen);
+  assert (system_event_record_data);
+
+  /* OEM Interpretation
+   *
+   * Quanta S99Q/Dell FS12-TY
+   */
+  if (ctx->product_id == IPMI_QUANTA_PRODUCT_ID_S99Q)
+    {
+      int nmret;
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data3_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+      
+      if (nmret)
+        return (1);
+    }
+
+  return (0);
+}
