@@ -158,10 +158,19 @@ ipmiconsole_ctx_config_setup (ipmiconsole_ctx_t c,
     strcpy (c->config.password, default_config.password);
 
   /* k_g may contain nulls */
-  if (ipmi_config->k_g && ipmi_config->k_g_len)
+  /* don't load defaults if k_g is not NULL */
+  if (ipmi_config->k_g)
     {
-      memcpy (c->config.k_g, ipmi_config->k_g, ipmi_config->k_g_len);
-      c->config.k_g_len = ipmi_config->k_g_len;
+      if (ipmi_config->k_g_len)
+	{
+	  memcpy (c->config.k_g, ipmi_config->k_g, ipmi_config->k_g_len);
+	  c->config.k_g_len = ipmi_config->k_g_len;
+	}
+      else
+	{
+	  memset (c->config.k_g, '\0', IPMI_MAX_K_G_LENGTH + 1);
+	  c->config.k_g_len = 0;
+	}
     }
   else
     {
@@ -207,7 +216,7 @@ ipmiconsole_ctx_config_setup (ipmiconsole_ctx_t c,
   else
     c->config.cipher_suite_id = default_config.cipher_suite_id;
 
-  if (ipmi_config->workaround_flags)
+  if (ipmi_config->workaround_flags != IPMICONSOLE_WORKAROUND_DEFAULT)
     c->config.workaround_flags = ipmi_config->workaround_flags;
   else
     c->config.workaround_flags = default_config.workaround_flags;
@@ -247,17 +256,17 @@ ipmiconsole_ctx_config_setup (ipmiconsole_ctx_t c,
   else
     c->config.maximum_retransmission_count = default_config.maximum_retransmission_count;
 
-  if (engine_config->engine_flags)
+  if (engine_config->engine_flags != IPMICONSOLE_ENGINE_DEFAULT)
     c->config.engine_flags = engine_config->engine_flags;
   else
     c->config.engine_flags = default_config.engine_flags;
 
-  if (engine_config->behavior_flags)
+  if (engine_config->behavior_flags != IPMICONSOLE_BEHAVIOR_DEFAULT)
     c->config.behavior_flags = engine_config->behavior_flags;
   else
     c->config.behavior_flags = default_config.behavior_flags;
   
-  if (engine_config->debug_flags)
+  if (engine_config->debug_flags != IPMICONSOLE_DEBUG_DEFAULT)
     c->config.debug_flags = engine_config->debug_flags;
   else
     c->config.debug_flags = default_config.debug_flags;
@@ -874,9 +883,15 @@ __ipmiconsole_ctx_connection_cleanup (ipmiconsole_ctx_t c, int session_submitted
     IPMICONSOLE_DEBUG (("pthread_mutex_unlock: %s", strerror (perr)));
 
   /* only call the callback if it's an initial SOL error and blocking
-   * was not requested
+   * was not requested and the session was submitted.  We do not want
+   * to call the callback if an error happened in API land and we are
+   * calling in via
+   * ipmiconsole_ctx_connection_cleanup_session_not_submitted().
    */
-  if (status_initial && !blocking_requested && c->non_blocking.callback)
+  if (status_initial
+      && !blocking_requested
+      && session_submitted
+      && c->non_blocking.callback)
     (*(c->non_blocking.callback))(c->non_blocking.callback_arg);
 
   /* Under default circumstances, close only the ipmiconsole_fd so
@@ -994,6 +1009,14 @@ __ipmiconsole_ctx_connection_cleanup (ipmiconsole_ctx_t c, int session_submitted
    * move this around.
    */
 
+  /* achu: See note in ipmiconsole_defs.h about the
+   * c->session_submitted flag.  That flag is only used in API land
+   * for the user to know if a session was submitted or not.  The
+   * session_submitted flag passed into this function is the "real"
+   * one that is known by the engine, and is not dependent on any race
+   * conditions with the API level.
+   */
+
   if (!session_submitted)
     return;
 
